@@ -1212,7 +1212,31 @@ void p3discovery2::recvPGPCertificate(const SSLID &/*fromId*/, RsDiscPgpCertItem
 
 	mPendingDiscPgpCertInList.push_back(item);
 }
-						  
+
+void p3discovery2::createPGPCertForSupernode(const RsPgpId &pgpid, std::string &cert)
+{
+    /* should only happen if in FULL Mode */
+
+    RsDiscPgpCertItem *item = new RsDiscPgpCertItem();
+    item->pgpId = pgpid;
+    item->pgpCert = cert;
+    peerState pstate;
+    mPeerMgr->getOwnNetStatus(pstate);
+    if (pstate.vs_disc != RS_VS_DISC_FULL)
+    {
+    #ifdef P3DISC_DEBUG
+        std::cerr << "p3discovery2::recvPGPCertificate() Not Loading Certificates as in MINIMAL MODE";
+        std::cerr << std::endl;
+    #endif
+
+        delete item;
+    }
+
+    RsStackMutex stack(mDiscMtx); /********** STACK LOCKED MTX ******/
+    /* push this back to be processed by pgp when possible */
+
+    mPendingDiscPgpCertInList.push_back(item);
+}
 				  
 						  
 						  
