@@ -42,7 +42,7 @@
 #include <algorithm>
 #include <time.h>
 
-#define CHAT_LOBBY_GUI_DEBUG 1
+//#define CHAT_LOBBY_GUI_DEBUG 1
 
 #define COLUMN_NAME       0
 //#define COLUMN_USER_COUNT 1
@@ -1615,7 +1615,7 @@ void ChatLobbyWidget::UpdateStatusForContact(QTreeWidgetItem* gpgItem , const Rs
     switch (statusContactInfo.status)
     {
         case RS_STATUS_INACTIVE:
-            gpgOverlayIcon = QPixmap(StatusDefs::imageStatus(RS_STATUS_OFFLINE));
+            gpgOverlayIcon = QPixmap(StatusDefs::imageStatus(RS_STATUS_AWAY));
             gpgFont.setBold(false);
             break;
 
